@@ -30,6 +30,7 @@ import org.apache.maven.model.Resource;
 import org.apache.maven.plugin.*;
 import org.apache.maven.project.MavenProject;
 import org.codehaus.plexus.util.StringUtils;
+import org.osgi.service.metatype.MetaTypeService;
 
 /**
  * The <code>SCRDescriptorMojo</code>
@@ -104,7 +105,7 @@ public class SCRDescriptorMojo extends AbstractMojo {
         final Components components = new Components();
         final Components abstractComponents = new Components();
         final MetaData metaData = new MetaData();
-        metaData.setLocalization("metatype");
+        metaData.setLocalization(MetaTypeService.METATYPE_DOCUMENTS_LOCATION + "/metatype");
 
         for (int i = 0; i < javaSources.length; i++) {
             this.getLog().debug("Testing source " + javaSources[i].getName());
@@ -345,7 +346,7 @@ public class SCRDescriptorMojo extends AbstractMojo {
 
         component.setEnabled(Boolean.valueOf(getBoolean(tag, Constants.COMPONENT_ENABLED, true)));
         component.setFactory(tag.getNamedParameter(Constants.COMPONENT_FACTORY));
-        
+
         // FELIX-593: immediate attribute does not default to true all the
         // times hence we only set it if declared in the tag
         if (tag.getNamedParameter(Constants.COMPONENT_IMMEDIATE) != null) {
@@ -403,13 +404,19 @@ public class SCRDescriptorMojo extends AbstractMojo {
         component.setService(service);
         boolean serviceFactory = false;
         for (int i=0; i < services.length; i++) {
-            String name = services[i].getNamedParameter(Constants.SERVICE_INTERFACE);
+            final String name = services[i].getNamedParameter(Constants.SERVICE_INTERFACE);
             if (StringUtils.isEmpty(name)) {
 
                 this.addInterfaces(service, services[i], description);
             } else {
+                // check if the value points to a class/interface
+                // and search through the imports
+                final JavaClassDescription serviceClass = description.getReferencedClass(name);
+                if ( serviceClass == null ) {
+                    throw new MojoExecutionException("Interface '"+ name + "' in class " + description.getName() + " does not point to a valid class/interface.");
+                }
                 final Interface interf = new Interface(services[i]);
-                interf.setInterfacename(name);
+                interf.setInterfacename(serviceClass.getName());
                 service.addInterface(interf);
             }
 
