@@ -87,6 +87,14 @@ public class ClassLoaderJavaClassDescription implements JavaClassDescription {
         throw new MojoExecutionException("getExternalFieldByName not support for this class.");
     }
 
+    /**
+     * @see org.apache.felix.scrplugin.tags.JavaClassDescription#getReferencedClass(java.lang.String)
+     */
+    public JavaClassDescription getReferencedClass(String referencedName)
+    throws MojoExecutionException {
+        throw new MojoExecutionException("getDescription not support for this class.");
+    }
+
     /**
      * @see org.apache.felix.scrplugin.tags.JavaClassDescription#getImplementedInterfaces()
      */
